----------------------------------------------------------------------------------------------------
--[[				LFG SCRUBBER
----------------------------------------------------------------------------------------------------

----- ABOUT

title:		LFG Scrubber
category:	Chat/Communication
notes:	Scans the LookingForGroup channel for groups of your level.
author:	Shaktar of Stonemaul/Zuluhed
date:		2006-09-18
version:	1.0

----- DESCRIPTION

LFG Scrubber scans the LookingForGroup and CTAChannel channels looking for LFG messages containing instances, zones, quests, and pvp groups that are your level. When one is found, it displays a message containing the full instance or zone name along with the original author and message.

To stop displaying all of the LookingForGroup messages, simply use the built-in channel filter in WoW and deselect the LookingForGroup channel. LFG Scrubber will continue to work and display groups around your level in your chat pane.

Nothing needs to be configured. All of the instances and zones are already known. Some of the commonly requested elite quests are also already known.

Scanning of messages is performed quickly. If a message contains LFG or similar term, then the message is broken down into individual words. Each word is checked against a dictionary of known areas. Each word check happens instantly since Lua uses hash tables to implement dictionaries, aka tables. The number of instances, zones, and quests in the dictionary does not affect the speed at which it finds a match. Messages not containing LFG or similar terms are not checked at all.

So, for example, "LF healer for UBRS" requires 3 checks for LFG/need/looking and 4 instant checks for the 4 words in the message for a total of 7 checks. UBRS would be found in the dictionary at a level range of 55-60. If you are level 55 or higher, you would be notified of this message.

Further filtering is performed such as not displaying repetitive messages or excessive exclamation points or messages while inside an instance.

----- INSTRUCTIONS

There is no configuration and no options to set other than slash commands to turn LFG Scrubber off or on. Everything is automatic. LFG messages for groups of your level are displayed in the chat frame. You can filter out the normal LookingForGroup messages by deselecting them in the channel filter built into WoW.

After installing LFG Scrubber and turning off LookingForGroup messages with WoW's channel filter, you may not see many LFG messages. This is normal. You will only see the LFG messages for your level. You will only see such messages outside of an instance unless you turn LFG Scrubber on inside the instance using a slash command.

If your level is less than 6, you will see LFG messages for all levels. This lets you check for groups while you are on a low-level alt.

You can click on the player link in any LFG message to send that player a tell.

]] -- edited with SciTE, best viewed using Verdana font and tabs and indents set to 8



----------------------------------------------------------------------------------------------------
----- GLOBAL VARIABLES
----------------------------------------------------------------------------------------------------

LFGS_on4session = true			-- slash command on/off is the only thing that can change this
LFGS_on4world = false			-- might log in inside instance, enter world event will set this
LFGS_timeAuthorsLastCleared = 0	-- list of authors cleared periodically to allow repeats every X minutes
LFGS_recentAuthors = { }		-- a list of author names for the past X number of minutes
LFGS_playerLevel = 0			-- enter world event will set this



----------------------------------------------------------------------------------------------------
----- CONSTANTS
----------------------------------------------------------------------------------------------------

LFGS_DEBUGGING = false				-- false
LFGS_FILTER_BY_LEVEL = true			-- true
LFGS_MAKE_PLAYER_LINK = true			-- true
LFGS_MINUTES_REPEATS_IGNORED = 10	-- 10

LFGS_PASTEL = '|cffffff80'				-- pastel yellow
LFGS_BRIGHT = '|cffffff00'				-- bright yellow

LFGS_LFG_CHANNEL_NAME = 'LookingForGroup'
LFGS_CTA_CHANNEL_NAME = 'CTAChannel'

LFGS_INSTRUCTIONS =
	LFGS_BRIGHT .. 'LFGS Scrubber ' .. LFGS_PASTEL .. 'by Shaktar\r' ..
	'Scans the LookingForGroup channel for groups of your level.\r' ..
	LFGS_BRIGHT .. '/lfgs on ' .. LFGS_PASTEL .. '- turns LFG Scrubber on\r' ..
	LFGS_BRIGHT .. '/lfgs off ' .. LFGS_PASTEL .. '- turns LFG Scrubber off'
LFGS_TURNED_ON = 'LFG Scrubber turned on.'
LFGS_TURNED_OFF = 'LFG Scrubber turned off.'

LFGS_START_LEVEL = 6
LFGS_LOADED = 'LFG Scrubber loaded. Type /lfgs for more info.'
LFGS_LOADED_NOT_STARTED =
	'LFG Scrubber loaded. Type /lfgs for more info.\r' ..
	'All group levels shown until you reach level ' .. LFGS_START_LEVEL .. '.'
LFGS_STARTED = 'LFG Scrubber started. Only groups of your level will show up now.'
LFGS_IN_INSTANCE = 'LFG Scrubber turned off inside of instances.'

LFGS_LF_SEARCH = 'LF[GM0-9 ]'
LFGS_NEED_SEARCH = 'NEED'
LFGS_LOOKING_SEARCH = 'LOOKING'

----------------------------------------------------------------------------------------------------

LFGS_variants = {

----- INSTANCES

aq20 = 'aq', aq40 = 'aq', ahnqiraj = 'aq', ruins = 'aq',
blackfathom = 'bfd',
ubrs = 'brs', urbs = 'brs', lbrs = 'brs', rend = 'brs', drak = 'brs', drakkisath = 'brs',
blackwing = 'bwl',
vc = 'deadmines',
dire = 'dm', tribute = 'dm',
gnome = 'gnomer', gnomeregan = 'gnomer',
maraudon = 'mara', maruadon = 'mara', mauradon = 'mara',
molten = 'mc',
nax = 'naxx',
onyx = 'onyxia',
ragefire = 'rfc',
scarlet = 'sm', scarlett = 'sm', armory = 'sm', lib = 'sm',
sholo = 'scholo', scholomance = 'scholo', sholomance = 'scholo',
shadowfang = 'sfk',
stockade = 'stock', stocks = 'stock',
strath = 'strat', baron = 'strat', udstrat = 'strat', livestrat = 'strat', ramstein = 'strat',
sunken = 'st',
uld = 'ulda', uldaman = 'ulda',
wailing = 'wc',
zulfarrak = 'zf', zulfarak = 'zf',
zulgurub = 'zg',

----- ZONES

sigil = 'arathi', fozruk = 'arathi', keystoneE = 'arathi',
northwatch = 'barrens', bristleback = 'barrens',
menaceE = 'burning',
eastern = 'epl', darrowshire = 'epl',
muisek = 'feralas',
perenolde = 'hillsbrad', willE = 'hillsbrad',
stonewatch = 'redridge', tharilzun = 'redridge', gathllzogg = 'redridge', morganth = 'redridge',
calling = 'silithus',
pyrewood = 'silverpine',
stranglethorn = 'stv', nesingwary = 'stv', nesingwarys = 'stv',
needles = 'thousand', grimtotem = 'thousand',
western = 'wpl', barov = 'wpl', frostwhisper = 'wpl', andorhal = 'wpl', araj = 'wpl',
watchtowers = 'wpl',

hillsbradE = 'garok', swordE = 'garok',							-- hillsbrad
jinth = 'jintha', jinthaalor = 'jintha', jinthalor = 'jintha', jin = 'jintha',	-- hinterlands
malkhors = 'jintha', jinthora = 'jintha',
stromgarde = 'strom', stromgard = 'strom', stormgarde = 'strom', stormgard = 'strom',	-- arathi

----- QUESTS

hetaera = 'beastE',						-- azshara
morbent = 'felE',						-- duskwood
warlords = 'wlc',						-- brs
somnus = 'skulls', scryer = 'skulls',			-- dustwallow
axtroz = 'skulls', chronalis = 'skulls',		-- dustwallow
borelgore = 'corpulent', grub = 'corpulent',	-- epl
NoVariantTest = 'novarianttest'

}

----------------------------------------------------------------------------------------------------

LFGS_areas = {

----- INSTANCES
aq =			{ name="Ahn'Qiraj", lo=60, hi=60 },
bfd =		{ name="Blackfathom Deeps", lo=24, hi=32 },
brd =		{ name="Blackrock Depths", lo=52, hi=60 },
brs =		{ name="Blackrock Spire", lo=55, hi=60 },
bwl =		{ name="Blackwing Lair", lo=60, hi=60 },
deadmines =	{ name="Deadmines", lo=17, hi=26 },
dm =		{ name="Dire Maul", lo=56, hi=60 },
gnomer =		{ name="Gnomeregan", lo=29, hi=38 },
mara =		{ name="Maraudon", lo=46, hi=55 },
mc =		{ name="Molten Core", lo=60, hi=60 },
naxx =		{ name="Naxxramas", lo=60, hi=60 },
onyxia =		{ name="Onyxia", lo=60, hi=60 },
rfc =			{ name="Ragefire Chasm", lo=13, hi=18 },
rfd =		{ name="Razorfen Downs", lo=37, hi=46 },
rfk =			{ name="Razorfen Kraul", lo=29, hi=38 },
scholo =		{ name="Scholomance", lo=58, hi=60 },
sm =		{ name="Scarlet Monastery", lo=34, hi=45 },
sfk =		{ name="Shadowfang Keep", lo=22, hi=30 },
stock =		{ name="The Stockade", lo=24, hi=32 },
strat =		{ name="Stratholme", lo=58, hi=60 },
st =			{ name="Sunken Temple", lo=50, hi=60 },
ulda =		{ name="Uldaman", lo=41, hi=51 },
wc =		{ name="Wailing Caverns", lo=17, hi =24 },
zf =			{ name="Zul'Farrak", lo=44, hi=54 },
zg =			{ name="Zul'Gurub", lo=60, hi=60 },

----- ZONES

alterac =		{ name="Alterac Mountains", lo=32, hi=44 },
arathi =		{ name="Arathi Highlands", lo=30, hi=46 },
ashenvale =	{ name="Ashenvale", lo=18, hi=34 },
azshara =	{ name="Azshara", lo=45, hi=60 },
badlands =	{ name="Badlands", lo=35, hi=48 },
barrens =	{ name="The Barrens", lo=10, hi=32 },
blasted =		{ name="Blasted Lands", lo=46, hi=60 },
burning =		{ name="Burning Steppes", lo=50, hi=60 },
darkshore =	{ name="Darkshore", lo=10, hi=26 },
desolace =	{ name="Desolace", lo=30, hi=42 },
durotar =		{ name="Durotar", lo=5, hi=14 },
duskwood =	{ name="Duskwood", lo=18, hi=38 },
dustwallow =	{ name="Dustwallow Marsh", lo=34, hi=46 },
epl =		{ name="Eastern Plaguelands", lo=53, hi=60 },
elwynn =		{ name="Elwynn Forest", lo=1, hi=12 },
felwood =	{ name="Felwood", lo=48, hi=60 },
feralas =		{ name="Feralas", lo=42, hi=54 },
hillsbrad =	{ name="Hillsbrad Foothills", lo=20, hi=44 },
hinterlands =	{ name="The Hinterlands", lo=42, hi=58 },
moonglade =	{ name="Moonglade", lo=54, hi=60 },
mulgore =	{ name="Mulgore", lo=1, hi=14 },
redridge =	{ name="Redridge Mountains", lo=14, hi=28 },
searing =		{ name="Searing Gorge", lo=43, hi=56 },
silithus =		{ name="Silithus", lo=52, hi=60 },
silverpine =	{ name="Silverpine Forest", lo=8, hi=24 },
stonetalon =	{ name="Stonetalon Mountains", lo=15, hi=32 },
stv =		{ name="Stranglethorn Vale", lo=28, hi=48 },
swamp =		{ name="Swamp of Sorrows", lo=34, hi=48 },
tanaris =		{ name="Tanaris", lo=42, hi=60 },
teldrassil =	{ name="Teldrassil", lo=1, hi=12 },
thousand =	{ name="Thousand Needles", lo=24, hi=46 },
tirisfal =		{ name="Tirisfal Glades", lo=1, hi=12 },
ungoro =		{ name="Un'Goro Crater", lo=48, hi=60 },
wpl =		{ name="Western Plaguelands", lo=50, hi=60 },
westfall =	{ name="Westfall", lo=10, hi=20 },
wetlands =	{ name="Wetlands", lo=20, hi=34 },

garok =		{ name="Dun Garok", lo=28, hi=44 },					-- hillsbrad
jintha =		{ name="Jintha'Alor", lo=46, hi=56 },					-- hinterlands
strom =		{ name="Stromgarde", lo=34, hi=46 },					-- arathi
tyrs =		{ name="Tyr's Hand", lo=54, hi=60 },					-- epl

----- QUESTS

princessE =	{ name="Summoning the Princess (Elite)", lo=40, hi=54 },	-- arathi
foulweald =	{ name="King of the Foulweald", lo=24, hi=30 },			-- ashenvale
sharptalon =	{ name="Sharptalon's Claw", lo=28, hi=34 },			-- ashenvale
beastE =		{ name="The Name of the Beast (Elite)", lo=48, hi=60 },	-- azshara
alliancesE =	{ name="Broken Alliances (Elite)", lo=46, hi=56 },			-- badlands
earthE =		{ name="Tremors of the Earth (Elite)", lo=46, hi=56 },		-- badlands
counterattack={ name="Counterattack!", lo=16, hi=26 },				-- barrens
kreenig =		{ name="The Disruption Ends", lo=9, hi=18 },			-- barrens
althalaxx =	{ name="The Tower of Althalaxx", lo=16, hi=36 },			-- darkshore
corrupterE =	{ name="The Corrupter (Elite)", lo=34, hi=48 },			-- desolace
hratha =		{ name="Khan Hratha (Elite)", lo=38, hi=50 },			-- desolace
embalmerE =	{ name="Bride of the Embalmer (Elite)", lo=24, hi=36 },	-- duskwood
felE =		{ name="Morbent Fel (Elite)", lo=26, hi=38 },			-- duskwood
morladim =	{ name="Mor'Ladim (Elite)", lo=28, hi=42 },				-- duskwood
skulls =		{ name="The Test of Skulls", lo=56, hi=60 },				-- dustwallow
duskwing =	{ name="Duskwing", lo=56, hi=60 },					-- epl
courierE =	{ name="The Crimson Courier", lo=60, hi=60 },			-- epl
corpulent =	{ name="The Corpulent One (Elite)", lo=56, hi=60 },		-- epl
sharpbeak =	{ name="Saving Sharpbeak (Elite)", lo=42, hi=60 },		-- hinterlands
shadra =		{ name="Summoning Shadra (Elite)", lo=44, hi=60 },		-- hinterlands
fenris =		{ name="Assault on Fenris Isle (Elite)", lo=18, hi=30 },		-- silverpine
maltorius =	{ name="WANTED: Overseer Maltorius (Elite)", lo=46, hi=58 },	-- searing
obsidianE =	{ name="Rise, Obsidian! (Elite)", lo=46, hi=58 },			-- searing
denE =		{ name="The Den (Elite)", lo=26, hi=36 },				-- stonetalon
endurance =	{ name="Test of Endurance", lo=25, hi=35 },			-- thousand
nekrosh =	{ name="Defeat Nek'rosh", lo=26, hi=34 },				-- wetlands

attunement =	{ name="Attunement to the Core", lo=55, hi=60 },		-- blackrock mountain
wlc =		{ name="Warlord's Command", lo=55, hi=60 },			-- brs

----- LEVELS

['10-19'] =	{ name='Levels 10-19', lo=10, hi=19 },
['20-29'] =	{ name='Levels 20-29', lo=20, hi=29 },
['30-39'] =	{ name='Levels 30-39', lo=30, hi=39 },
['40-49'] =	{ name='Levels 40-49', lo=40, hi=49 },
['50-60'] =	{ name='Levels 50-60', lo=50, hi=60 },
['60'] =		{ name='Level 60', lo=56, hi=60 },
high =		{ name='High Levels', lo=56, hi=60 },

['[10]'] =		{ name='Level 10 Quest', lo=2, hi=18 },
['[11]'] =		{ name='Level 11 Quest', lo=3, hi=19 },
['[12]'] =		{ name='Level 12 Quest', lo=4, hi=20 },
['[13]'] =		{ name='Level 13 Quest', lo=5, hi=21 },
['[14]'] =		{ name='Level 14 Quest', lo=6, hi=22 },
['[15]'] =		{ name='Level 15 Quest', lo=7, hi=23 },
['[16]'] =		{ name='Level 16 Quest', lo=8, hi=24 },
['[17]'] =		{ name='Level 17 Quest', lo=9, hi=25 },
['[18]'] =		{ name='Level 18 Quest', lo=10, hi=26 },
['[19]'] =		{ name='Level 19 Quest', lo=11, hi=27 },

['[20]'] =		{ name='Level 20 Quest', lo=12, hi=28 },
['[21]'] =		{ name='Level 21 Quest', lo=13, hi=29 },
['[22]'] =		{ name='Level 22 Quest', lo=14, hi=30 },
['[23]'] =		{ name='Level 23 Quest', lo=15, hi=31 },
['[24]'] =		{ name='Level 24 Quest', lo=16, hi=32 },
['[25]'] =		{ name='Level 25 Quest', lo=17, hi=33 },
['[26]'] =		{ name='Level 26 Quest', lo=18, hi=34 },
['[27]'] =		{ name='Level 27 Quest', lo=19, hi=35 },
['[28]'] =		{ name='Level 28 Quest', lo=20, hi=36 },
['[29]'] =		{ name='Level 29 Quest', lo=21, hi=37 },

['[30]'] =		{ name='Level 30 Quest', lo=22, hi=38 },
['[31]'] =		{ name='Level 31 Quest', lo=23, hi=39 },
['[32]'] =		{ name='Level 32 Quest', lo=24, hi=40 },
['[33]'] =		{ name='Level 33 Quest', lo=25, hi=41 },
['[34]'] =		{ name='Level 34 Quest', lo=26, hi=42 },
['[35]'] =		{ name='Level 35 Quest', lo=27, hi=43 },
['[36]'] =		{ name='Level 36 Quest', lo=28, hi=44 },
['[37]'] =		{ name='Level 37 Quest', lo=29, hi=45 },
['[38]'] =		{ name='Level 38 Quest', lo=30, hi=46 },
['[39]'] =		{ name='Level 39 Quest', lo=31, hi=47 },

['[40]'] =		{ name='Level 40 Quest', lo=32, hi=48 },
['[41]'] =		{ name='Level 41 Quest', lo=33, hi=49 },
['[42]'] =		{ name='Level 42 Quest', lo=34, hi=50 },
['[43]'] =		{ name='Level 43 Quest', lo=35, hi=51 },
['[44]'] =		{ name='Level 44 Quest', lo=36, hi=52 },
['[45]'] =		{ name='Level 45 Quest', lo=37, hi=53 },
['[46]'] =		{ name='Level 46 Quest', lo=38, hi=54 },
['[47]'] =		{ name='Level 47 Quest', lo=39, hi=55 },
['[48]'] =		{ name='Level 48 Quest', lo=40, hi=56 },
['[49]'] =		{ name='Level 49 Quest', lo=41, hi=57 },

['[50]'] =		{ name='Level 50 Quest', lo=42, hi=58 },
['[51]'] =		{ name='Level 51 Quest', lo=43, hi=59 },
['[52]'] =		{ name='Level 52 Quest', lo=44, hi=60 },
['[53]'] =		{ name='Level 53 Quest', lo=45, hi=60 },
['[54]'] =		{ name='Level 54 Quest', lo=46, hi=60 },
['[55]'] =		{ name='Level 55 Quest', lo=47, hi=60 },
['[56]'] =		{ name='Level 56 Quest', lo=48, hi=60 },
['[57]'] =		{ name='Level 57 Quest', lo=49, hi=60 },
['[58]'] =		{ name='Level 58 Quest', lo=50, hi=60 },
['[59]'] =		{ name='Level 59 Quest', lo=51, hi=60 },

['[60]'] =		{ name='Level 60 Quest', lo=52, hi=60 }

}

----------------------------------------------------------------------------------------------------

LFGS_tests = {


"lfg aq20",
"lfg aq20",	-- should not display since it's a recent repeat
"lfg Ahn'Qiraj",
"lfg Assault on Fenris Isle (Elite)",
"lfg elite hinterlands quests",
"lfg rend run",
"lfg dm west",
"lfg maruadon",
"lfg baron run",
"lfg Zul'Farak",
"lfg western plagelands quests",
"lfg Eastern Plaguelands quests",
"lfg Stranglethorn Vale group",
"lfg Un'Goro Crater",
"lfg in Dun Garok",
"lfg Jintha'lor",
"lfg Jinth'alor",
"lfg jintha",
"lfg stromgard badges",
"lfg tyrs group",
"lfg tyr's hand",
"lfg Summoning the Princess (Elite)",
"lfg foulweald quest",
"lfg to kill sharptalon",
"lfg Counterattack!",
"lfg need Kreenig Snarlsnout's Tusk",
"lfg morladim",
"lfg morbent",
"lfg Morbent Fel (Elite)",
"lfg test of skulls, aztroz",
"lfg skulls",
"lfg duskwing bat",
"lfg Duskwing, Oh How I Hate Thee... (Elite)",
"lfg save sharpbeak",
"lfg Rise, Obsidian! (Elite)",
"lfg Test of Endurance",
"lfg warlord's",
"lfg Alas, Andorhal... (Elite)",
"lfg ubrs...priest",
"lfm garok",
"lf1m garok",
"lfxm garok",
"lf garok",
"garok lfg",
"need garok",
"garok elf garok",
"garok lf",
"lfm [14] Samophlange",
"lfm WSG 10-19",
"60 warrior lfg"

}





----------------------------------------------------------------------------------------------------
----- FUNCTIONS
----------------------------------------------------------------------------------------------------

----------------------------------------------------------------------------------------------------
function LFGS_time()
----------------------------------------------------------------------------------------------------
if (GetTime) then return GetTime() end
if (os and os.time) then return os.time() end
return 0
end

----------------------------------------------------------------------------------------------------
function LFGS_Chat(message)
----------------------------------------------------------------------------------------------------
----- displays message on the chat frame
if (not message or not DEFAULT_CHAT_FRAME) then return end
DEFAULT_CHAT_FRAME:AddMessage(message)
end

----------------------------------------------------------------------------------------------------
function LFGS_Debug(name, value)
----------------------------------------------------------------------------------------------------
if (not LFGS_DEBUGGING) then return end
LFGS_Chat(tostring(name) .. ' = ' .. tostring(value))
end

----------------------------------------------------------------------------------------------------
function LFGS_DoLoad()
----------------------------------------------------------------------------------------------------
this:RegisterEvent('PLAYER_LOGIN')
this:RegisterEvent('PLAYER_ENTERING_WORLD')
this:RegisterEvent('PLAYER_LEVEL_UP')
this:RegisterEvent('CHAT_MSG_CHANNEL')
SlashCmdList['LFG_Scrubber'] = LFGS_DoSlash
SLASH_LFG_Scrubber1 = '/lfgs'
end

----------------------------------------------------------------------------------------------------
function LFGS_DoSlash(cmd)
----------------------------------------------------------------------------------------------------

if (string.upper(cmd) == 'ON') then
	LFGS_on4session = true
	LFGS_on4world = true		-- turn on even inside an instance
	LFGS_Chat(LFGS_TURNED_ON)
	return end

if (string.upper(cmd) == 'OFF') then
	LFGS_on4session = false	-- turn off completely
	LFGS_on4world = false
	LFGS_Chat(LFGS_TURNED_OFF)
	return end

if (LFGS_DEBUGGING and string.upper(cmd) == 'SCREEN') then
	LFGS_timeAuthorsLastCleared = 0
	local on4session = LFGS_on4session
	local on4world = LFGS_on4world
	LFGS_on4session = true
	LFGS_on4world = true
	LFGS_DoScreenshot()
	LFGS_on4session = on4session
	LFGS_on4world = on4world
	return end
	
LFGS_Chat(LFGS_INSTRUCTIONS)
end
	
----------------------------------------------------------------------------------------------------
function LFGS_DoEvent(event)
----------------------------------------------------------------------------------------------------

if (event == 'CHAT_MSG_CHANNEL') then
	if (not LFGS_on4session or not LFGS_on4world) then return end
	if (arg9 == LFGS_LFG_CHANNEL_NAME) then		-- arg9 = channelName
		LFGS_DoChannelEvent(arg1, arg2) end		-- arg1 = chatMessage, arg2 = author
	if (arg9 == LFGS_CTA_CHANNEL_NAME) then
		LFGS_DoCTAChannelEvent(arg1) end
	end

if (event == 'PLAYER_LOGIN') then
	JoinChannelByName(LFGS_LFG_CHANNEL_NAME)
	JoinChannelByName(LFGS_CTA_CHANNEL_NAME)
	LFGS_playerLevel = UnitLevel('player')
	if (LFGS_playerLevel >= LFGS_START_LEVEL)
		then LFGS_Chat(LFGS_LOADED)
		else LFGS_Chat(LFGS_LOADED_NOT_STARTED)
		end
	end

if (event == 'PLAYER_ENTERING_WORLD') then
	if (not LFGS_on4session) then return end
	if (IsInInstance()) then
		LFGS_on4world = false
		LFGS_Chat(LFGS_IN_INSTANCE)
	else
		LFGS_on4world = true
		end
	end

if (event == 'PLAYER_LEVEL_UP') then
	LFGS_playerLevel = arg1			-- arg1 = new level
	if (LFGS_playerLevel == LFGS_START_LEVEL) then
		LFGS_Chat(LFGS_STARTED) end
	end

end

----------------------------------------------------------------------------------------------------
function LFGS_DoCTAChannelEvent(cta)
----------------------------------------------------------------------------------------------------
local t1, t2, author = string.find(cta, '/cta [^:]+:([^:]+)')
local t1, t2, message = string.find(cta, '/cta [^:]+:[^:]+:([^:]+)')
LFGS_DoChannelEvent(message, author)
end

----------------------------------------------------------------------------------------------------
function LFGS_DoChannelEvent(message, author)
----------------------------------------------------------------------------------------------------

----- exit if no author or message
if (not author) then LFGS_Debug('author', author) return end
if (not message) then LFGS_Debug('message', message) return end

----- message should contain LFG or LFM or LF# or LF or Need
local containsLFG = string.find(string.upper(message), LFGS_LF_SEARCH)
local containsNeed = string.find(string.upper(message), LFGS_NEED_SEARCH)
local containsLooking = string.find(string.upper(message), LFGS_LOOKING_SEARCH)
if (not containsLFG and not containsNeed and not containsLooking) then return end

----- swap case to lower since all keys are lowercase except E suffix for elite quests
local search = string.lower(message)

----- replace (Elite) with the word preceding Elite plus the letter E
----- example: "lfg the den (elite)" becomes "lfg the den denE"
----- this makes searches for elite quests much more precise
----- can now search for denE which will only match the elite den quest
----- it will not match non-elite den quests such as "lfg the grizzled den"
search = string.gsub(search, '(%w+)%p* %(elite%)', '%1 %1E')

----- remove apostrophes since instance names contain apostrophes
----- otherwise, names such as Zul'Farrak will be split into Zul and Farrak
search = string.gsub(search, "'", '')

----- find the first recognized search term in the LFGS_Debug message
----- dashes and braces [] must be included to find numbers such as [15] and 10-19
----- this means terms such as brd-bwl or [brd] will not match anything
local variant
local area
local found
for word in string.gfind(search, '[%w-%[%]]+') do
	--LFGS_Debug('word', word)
	variant = LFGS_variants[word]
	--LFGS_Debug('variant', variant)
	if (variant) then word = variant end
	area = LFGS_areas[word]
	found = variant or area
	if (found) then break end
	end
if (not found) then LFGS_Debug('LFG [NOTHING FOUND]', message) return end
if (not area) then LFGS_Debug('LFG [VARIANT NOT LISTED IN AREAS]', variant) return end

----- only display if area matches player's level
if (LFGS_FILTER_BY_LEVEL and LFGS_playerLevel >= LFGS_START_LEVEL) then
	if (area.lo > LFGS_playerLevel) then return end
	if (area.hi < LFGS_playerLevel) then return end
	end

----- message should not be from a recent author within a certain number of minutes
if ((LFGS_time() - LFGS_timeAuthorsLastCleared) / 60 > LFGS_MINUTES_REPEATS_IGNORED) then
	LFGS_recentAuthors = { }
	LFGS_timeAuthorsLastCleared = LFGS_time()
	end
if (author ~= 'test' and LFGS_recentAuthors[author]) then return end
LFGS_recentAuthors[author] = true

----- DeSpam: decapitalize if all caps and remove exclamations
if (message == string.upper(message)) then
	message = string.lower(message) end
if (string.find(message, '!!')) then
	message = string.gsub(message, '!', '') end

----- display area name and chat message
local lfgtext = 'LFG'
local playerlink = author
if (LFGS_MAKE_PLAYER_LINK) then
	lfgtext = LFGS_PASTEL .. 'LFG|r'
	playerlink = '|Hplayer:' .. author .. '|h[' .. author .. ']|h'
	end
LFGS_Chat(lfgtext .. ' [' .. area.name .. '] ' .. playerlink .. ': ' .. message)

end

----------------------------------------------------------------------------------------------------
function LFGS_DoScreenshot()
----------------------------------------------------------------------------------------------------

LFGS_DoChannelEvent('LF Healer for UBRS', 'Upcreek')
LFGS_DoChannelEvent('LF2M to kill Axtroz', 'Cinder')
LFGS_DoChannelEvent('lfg to do epl quests', 'Sick')
LFGS_DoChannelEvent('need more for elite stormgard quests', 'Misspeller')
end

----------------------------------------------------------------------------------------------------
function LFGS_DoTests()
----------------------------------------------------------------------------------------------------

LFGS_playerLevel = 38

if (false) then
	LFGS_DoChannelEvent('lfg rfc]', 'test')		-- will not find due to bracket
	LFGS_DoChannelEvent('lfg aq-zq', 'test')	-- will not find due to dash
	LFGS_DoChannelEvent('lfg aq,zq', 'test')		-- will find
	LFGS_DoChannelEvent('lfg AQ!', 'test')		-- will find
	LFGS_DoChannelEvent('LFG AQ!', 'test')		-- will find (and change to lowercase)
	LFGS_DoChannelEvent('lfg AQ!!!', 'test')		-- will find (and remove exclamations)
	end

if (false) then
	LFGS_DoChannelEvent('lfg skulls', 'sop')
	LFGS_DoChannelEvent('lf1m sm', 'Zubzer')
	LFGS_DoCTAChannelEvent('/cta D<1340:Subzero:LFG SM:x>')
	LFGS_DoCTAChannelEvent('/cta D<1340:Subzer:LFM SM:x>')
	end

if (false) then
	LFGS_DoChannelEvent('lfg aq', 'a')
	LFGS_DoChannelEvent('lfg bfd', 'b')
	LFGS_DoChannelEvent('lfg brd', 'c')
	LFGS_DoChannelEvent('lfg brs', 'd')
	LFGS_DoChannelEvent('lfg bwl', 'e')
	LFGS_DoChannelEvent('lfg bfd', 'f')		-- message repeat
	LFGS_DoChannelEvent('lfg bfd', 'b')		-- author+message repeat
	LFGS_DoChannelEvent('lfg bfd', 'g')		-- message repeat
	LFGS_DoChannelEvent('lfg brd', 'c')		-- author+message repeat
	LFGS_DoChannelEvent('lfg zg', 'a')		-- author repeat
	end	-- should show messages from authors abcdefg

if (false) then
	for key in LFGS_tests do
		LFGS_DoChannelEvent(LFGS_tests[key], 'test') end
	end

if (false) then
	for key in LFGS_variants do
		LFGS_Debug(key, LFGS_areas[LFGS_variants[key]]) end
	end

end

----------------------------------------------------------------------------------------------------

--LFGS_DoTests()

